@@ -9,9 +9,10 @@
 
 // Qt
 #include <QString>
+// Std
+#include <memory>
 
 class BoardLayout;
-class KMahjonggLayoutPrivate;
 
 class KMahjonggLayout
 {
@@ -22,15 +23,23 @@ public:
     bool load(const QString & file);
     bool loadDefault();
     QString path() const;
-    QString authorProperty(const QString & key) const;
+
+    QString name() const;
+    QString description() const;
+    QString authorName() const;
+    QString authorEmailAddress() const;
+
     BoardLayout * board() const;
-    QString layoutName() const;
 
 private:
-    friend class KMahjonggLayoutPrivate;
-    KMahjonggLayoutPrivate * const d;
-    QString filename;
-    QString m_layoutName;
+    QString m_fileName;
+
+    QString m_name;
+    QString m_description;
+    QString m_authorName;
+    QString m_authorEmailAddress;
+
+    std::unique_ptr<BoardLayout> const m_board;
 
     Q_DISABLE_COPY(KMahjonggLayout)
 };
